from .exceptions import RateLimitError, ServerNotResponsiveError, CommandsNotEnabledError, ResponseNotRecievedError, \
    PrefixNotDefinedError, ImageError, ClientNotConnectedError, RequestError, SmartDeviceRegistrationError
